import request from '@/utils/request'

// 查询专病路径信息列表
export function listSpecialDiseaseRoute(query) {
    return request({
        url: '/system/specialDiseaseRoute/list',
        method: 'get',
        params: query
    })
}

// 查询专病路径信息详细
export function getSpecialDiseaseRoute(id) {
    return request({
        url: '/system/specialDiseaseRoute/' + id,
        method: 'get'
    })
}

// 新增专病路径信息
export function addSpecialDiseaseRoute(data) {
    return request({
        url: '/system/specialDiseaseRoute/add',
        method: 'post',
        data: data
    })
}

//删除主路径
export function specialDiseaseRoutedel(id) {
    return request({
        url: `/system/specialDiseaseRoute/${id}`,
        method: 'delete'
    })
}

// 修改专病路径信息
export function updateSpecialDiseaseRoute(data) {
    return request({
        url: '/system/specialDiseaseRoute/edit',
        method: 'put',
        data: data
    })
}

//科室
export function selectDiseaseCount(departmentName, releaseStatus, servicePackageId) {
    return request({
        url: `/system/specialDiseaseRoute/departmentRouteCount?departmentName=${departmentName}&releaseStatus=${releaseStatus}&servicePackageId=${servicePackageId}`,
        method: 'get',

    })
}
//所属科室
export function getDepartmentList(query) {
    return request({
        url: '/system/department/getDepartmentList',
        method: 'get',
        params: query
    })
}
//所属病区
export function getdiseaseList(query) {
    return request({
        url: '/system/departmentDisease/diseaseList',
        method: 'get',
        params: query
    })
}


//发布
export function editReleaseStatus(data) {
    return request({
        url: '/system/specialDiseaseRoute/editReleaseStatus',
        method: 'post',
        data: data
    })
}